@@ -28,17 +28,17 @@ LOG = logging.getLogger(__name__)
 class DesignateContext(context.RequestContext):
 
     _all_tenants = False
+    _hide_counts = False
     _abandon = None
     original_tenant = None
     _edit_managed_records = False
 
     def __init__(self, service_catalog=None, all_tenants=False, abandon=None,
                  tsigkey_id=None, user_identity=None, original_tenant=None,
-                 edit_managed_records=False, **kwargs):
+                 edit_managed_records=False, hide_counts=False, **kwargs):
 
         # NOTE: user_identity may be passed in, but will be silently dropped as
         #       it is a generated field based on several others.
-
         super(DesignateContext, self).__init__(**kwargs)
 
         self.service_catalog = service_catalog
@@ -49,6 +49,7 @@ class DesignateContext(context.RequestContext):
         self.all_tenants = all_tenants
         self.abandon = abandon
         self.edit_managed_records = edit_managed_records
+        self.hide_counts = hide_counts
 
     def deepcopy(self):
         d = self.to_dict()
@@ -77,12 +78,12 @@ class DesignateContext(context.RequestContext):
         d.update({
             'user_identity': user_idt,
             'original_tenant': self.original_tenant,
-            'roles': self.roles,
             'service_catalog': self.service_catalog,
             'all_tenants': self.all_tenants,
             'abandon': self.abandon,
             'edit_managed_records': self.edit_managed_records,
-            'tsigkey_id': self.tsigkey_id
+            'tsigkey_id': self.tsigkey_id,
+            'hide_counts': self.hide_counts
         })
 
         return copy.deepcopy(d)
@@ -91,8 +92,11 @@ class DesignateContext(context.RequestContext):
     def from_dict(cls, values):
         return cls(**values)
 
-    def elevated(self, show_deleted=None):
-        """Return a version of this context with admin flag set."""
+    def elevated(self, show_deleted=None, all_tenants=False,
+                 edit_managed_records=False):
+        """Return a version of this context with admin flag set.
+        Optionally set all_tenants and edit_managed_records
+        """
         context = self.deepcopy()
         context.is_admin = True
 
@@ -102,6 +106,12 @@ class DesignateContext(context.RequestContext):
         if show_deleted is not None:
             context.show_deleted = show_deleted
 
+        if all_tenants:
+            context.all_tenants = True
+
+        if edit_managed_records:
+            context.edit_managed_records = True
+
         return context
 
     def sudo(self, tenant):
@@ -146,6 +156,14 @@ class DesignateContext(context.RequestContext):
             policy.check('all_tenants', self)
         self._all_tenants = value
 
+    @property
+    def hide_counts(self):
+        return self._hide_counts
+
+    @hide_counts.setter
+    def hide_counts(self, value):
+        self._hide_counts = value
+
     @property
     def abandon(self):
         return self._abandon
