@@ -15,7 +15,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import logging
 
 import six
 import sqlalchemy
@@ -24,13 +23,24 @@ from sqlalchemy import select
 from oslo_db.sqlalchemy import utils
 from oslo_db import exception as oslo_db_exception
 from oslo_db.sqlalchemy.migration_cli import manager
+from oslo_log import log
 
 from designate.i18n import _
 from designate.i18n import _LW
 from designate import exceptions
 
 
-LOG = logging.getLogger(__name__)
+LOG = log.getLogger(__name__)
+
+RRSET_FILTERING_INDEX = {
+    'created_at': 'recordset_created_at',
+    'updated_at': 'rrset_updated_at',
+    'zone_id': 'rrset_zoneid',
+    'name': 'recordset_type_name',
+    'type': 'rrset_type',
+    'ttl': 'rrset_ttl',
+    'tenant_id': 'rrset_tenant_id',
+}
 
 
 def get_migration_manager(repo_path, url, init_version=None):
@@ -140,3 +150,13 @@ def check_marker(table, marker, session):
             raise
 
     return marker
+
+
+def get_rrset_index(sort_key):
+    rrset_index_hint = None
+    index = RRSET_FILTERING_INDEX.get(sort_key)
+
+    if index:
+        rrset_index_hint = 'USE INDEX (%s)' % index
+
+    return rrset_index_hint
