@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Federico Ceratto <federico.ceratto@hp.com>
+# Author: Federico Ceratto <federico.ceratto@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -26,131 +26,131 @@ from designate import objects
 LOG = logging.getLogger(__name__)
 
 
-def create_test_domain():
-    return objects.Domain(
+def create_test_zone():
+    return objects.Zone(
         name='www.example.org.',
         email='foo@example.com',
     )
 
 
-class DomainTest(oslotest.base.BaseTestCase):
+class zoneTest(oslotest.base.BaseTestCase):
 
     def test_init(self):
-        domain = create_test_domain()
-        self.assertEqual(domain.name, 'www.example.org.')
+        zone = create_test_zone()
+        self.assertEqual('www.example.org.', zone.name)
 
     def test_masters_none(self):
-        domain = objects.Domain()
+        zone = objects.Zone()
         with testtools.ExpectedException(exceptions.RelationNotLoaded):
-            self.assertEqual(domain.masters, None)
+            self.assertIsNone(zone.masters)
 
     def test_masters(self):
-        domain = objects.Domain(
-            masters=objects.DomainMasterList.from_list([
+        zone = objects.Zone(
+            masters=objects.ZoneMasterList.from_list([
                 {'host': '1.0.0.0', 'port': 53}
             ])
         )
         self.assertEqual(
-            domain.masters.to_list(), [{'host': '1.0.0.0', 'port': 53}])
+            [{'host': '1.0.0.0', 'port': 53}], zone.masters.to_list())
 
     def test_masters_2(self):
-        domain = objects.Domain(
-            masters=objects.DomainMasterList.from_list([
+        zone = objects.Zone(
+            masters=objects.ZoneMasterList.from_list([
                 {'host': '1.0.0.0'},
                 {'host': '2.0.0.0'}
             ])
         )
-        self.assertEqual(len(domain.masters), 2)
+        self.assertEqual(2, len(zone.masters))
 
     def test_get_master_by_ip(self):
-        domain = objects.Domain(
-            masters=objects.DomainMasterList.from_list([
+        zone = objects.Zone(
+            masters=objects.ZoneMasterList.from_list([
                 {'host': '1.0.0.0', 'port': 53},
                 {'host': '2.0.0.0', 'port': 53}
             ])
         )
-        m = domain.get_master_by_ip('2.0.0.0').to_data()
+        m = zone.get_master_by_ip('2.0.0.0').to_data()
 
-        self.assertEqual(m, '2.0.0.0:53')
+        self.assertEqual('2.0.0.0:53', m)
 
-    @unittest.expectedFailure  # bug: domain.masters is not iterable
+    @unittest.expectedFailure  # bug: zone.masters is not iterable
     def test_get_master_by_ip_none(self):
-        domain = objects.Domain()
-        m = domain.get_master_by_ip('2.0.0.0')
-        self.assertEqual(m, False)
+        zone = objects.Zone()
+        m = zone.get_master_by_ip('2.0.0.0')
+        self.assertFalse(m)
 
     def test_validate(self):
-        domain = create_test_domain()
-        domain.validate()
+        zone = create_test_zone()
+        zone.validate()
 
     def test_validate_invalid_secondary(self):
-        domain = objects.Domain(
+        zone = objects.Zone(
             type='SECONDARY',
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
 
     def test_validate_primary_with_masters(self):
-        masters = objects.DomainMasterList()
-        masters.append(objects.DomainMaster.from_data("10.0.0.1:53"))
-        domain = objects.Domain(
+        masters = objects.ZoneMasterList()
+        masters.append(objects.ZoneMaster.from_data("10.0.0.1:53"))
+        zone = objects.Zone(
             name='example.com.',
             type='PRIMARY',
             email="foo@example.com",
             masters=masters
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
 
     def test_validate_primary_no_email(self):
-        masters = objects.DomainMasterList()
-        masters.append(objects.DomainMaster.from_data("10.0.0.1:53"))
-        domain = objects.Domain(
+        masters = objects.ZoneMasterList()
+        masters.append(objects.ZoneMaster.from_data("10.0.0.1:53"))
+        zone = objects.Zone(
             name='example.com.',
             type='PRIMARY',
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
 
     def test_validate_secondary_with_email(self):
-        masters = objects.DomainMasterList()
-        masters.append(objects.DomainMaster.from_data("10.0.0.1:53"))
-        domain = objects.Domain(
+        masters = objects.ZoneMasterList()
+        masters.append(objects.ZoneMaster.from_data("10.0.0.1:53"))
+        zone = objects.Zone(
             name='example.com.',
             type='SECONDARY',
             email="foo@example.com",
             masters=masters
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
 
     def test_validate_secondary_with_ttl(self):
-        masters = objects.DomainMasterList()
-        masters.append(objects.DomainMaster.from_data("10.0.0.1:53"))
-        domain = objects.Domain(
+        masters = objects.ZoneMasterList()
+        masters.append(objects.ZoneMaster.from_data("10.0.0.1:53"))
+        zone = objects.Zone(
             name='example.com.',
             type='SECONDARY',
             ttl=600,
             masters=masters
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
 
     def test_validate_secondary_with_masters_empty_list(self):
-        masters = objects.DomainMasterList()
-        domain = objects.Domain(
+        masters = objects.ZoneMasterList()
+        zone = objects.Zone(
             name='example.com.',
             type='SECONDARY',
             masters=masters
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
 
     def test_validate_secondary_with_masters_none(self):
-        domain = objects.Domain(
+        zone = objects.Zone(
             name='example.com.',
             type='SECONDARY',
             masters=None
         )
         with testtools.ExpectedException(exceptions.InvalidObject):
-            domain.validate()
+            zone.validate()
