@@ -15,7 +15,7 @@ limitations under the License.
 """
 
 from oslo_config import cfg
-from tempest_lib import exceptions
+from tempest.lib import exceptions
 
 from functionaltests.api.v2.clients.quotas_client import QuotasClient
 from functionaltests.api.v2.clients.tld_client import TLDClient
@@ -36,7 +36,10 @@ class DesignateV2Test(BaseDesignateTest):
                     'zones': 9999999,
                     'recordset_records': 9999999,
                     'zone_records': 9999999,
-                    'zone_recordsets': 9999999}}))
+                    'zone_recordsets': 9999999
+                }
+            })
+        )
 
     def ensure_tld_exists(self, tld='com'):
         if cfg.CONF.testconfig.no_admin_setup:
