@@ -14,7 +14,6 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 import dns.rdatatype
-from tempest_lib import exceptions
 
 from functionaltests.common import datagen
 from functionaltests.common import dnsclient
@@ -78,13 +77,24 @@ class RecordsetTest(DesignateV2Test):
         self.ensure_tld_exists('com')
         self.zone = self.useFixture(ZoneFixture()).created_zone
 
-    def test_list_recordsets(self):
-        post_model = datagen.random_a_recordset(self.zone.name)
+    def test_list_recordsets_with_filtering(self):
+        # This test ensures the behavior in bug #1561746 won't happen
+        post_model = datagen.random_a_recordset(self.zone.name,
+                                                ip='192.168.1.2')
         self.useFixture(RecordsetFixture(self.zone.id, post_model))
+        for i in range(1, 3):
+            post_model = datagen.random_a_recordset(self.zone.name,
+                                                    ip='10.0.1.{}'.format(i))
+            self.useFixture(RecordsetFixture(self.zone.id, post_model))
+
+        # Add limit in filter to make response paginated
+        filters = {"data": "10.*", "limit": 2}
         resp, model = RecordsetClient.as_user('default') \
-            .list_recordsets(self.zone.id)
+            .list_recordsets(self.zone.id, filters=filters)
         self.assertEqual(200, resp.status)
-        self.assertGreater(len(model.recordsets), 0)
+        self.assertEqual(2, model.metadata.total_count)
+        self.assertEqual(len(model.recordsets), 2)
+        self.assertIsNotNone(model.links.next)
 
     def assert_dns(self, model):
         results = dnsclient.query_servers(model.name, model.type)
@@ -109,36 +119,6 @@ class RecordsetTest(DesignateV2Test):
 
             self.assertEqual(model_data, data)
 
-    @utils.parameterized(RECORDSETS_DATASET)
-    def test_crud_recordset(self, make_recordset):
-        post_model = make_recordset(self.zone)
-        fixture = self.useFixture(RecordsetFixture(self.zone.id, post_model))
-        recordset_id = fixture.created_recordset.id
-
-        self.assert_dns(fixture.post_model)
-
-        put_model = make_recordset(self.zone)
-        del put_model.name  # don't try to update the name
-        resp, put_resp_model = RecordsetClient.as_user('default') \
-            .put_recordset(self.zone.id, recordset_id, put_model)
-        self.assertEqual(202, resp.status, "on put response")
-        self.assertEqual("PENDING", put_resp_model.status)
-        self.assertEqual(post_model.name, put_resp_model.name)
-        self.assertEqual(put_model.records, put_resp_model.records)
-        self.assertEqual(put_model.ttl, put_resp_model.ttl)
-
-        RecordsetClient.as_user('default').wait_for_recordset(
-            self.zone.id, recordset_id)
-
-        put_model.name = post_model.name
-        self.assert_dns(put_model)
-
-        resp, delete_resp_model = RecordsetClient.as_user('default') \
-            .delete_recordset(self.zone.id, recordset_id)
-        self.assertEqual(202, resp.status, "on delete response")
-        RecordsetClient.as_user('default').wait_for_404(
-            self.zone.id, recordset_id)
-
     @utils.parameterized(WILDCARD_RECORDSETS_DATASET)
     def test_can_create_and_query_wildcard_recordset(self, make_recordset):
         post_model = make_recordset(self.zone)
@@ -153,53 +133,3 @@ class RecordsetTest(DesignateV2Test):
 
         for m in verify_models:
             self.assert_dns(m)
-
-
-class RecordsetOwnershipTest(DesignateV2Test):
-
-    def setUp(self):
-        super(RecordsetOwnershipTest, self).setUp()
-        self.increase_quotas(user='default')
-        self.increase_quotas(user='alt')
-        self.ensure_tld_exists('com')
-
-    def test_no_create_recordset_by_alt_tenant(self):
-        zone = self.useFixture(ZoneFixture(user='default')).created_zone
-
-        # try with name=A123456.zone.com.
-        recordset = datagen.random_a_recordset(zone_name=zone.name)
-        self.assertRaises(exceptions.RestClientException,
-            lambda: RecordsetClient.as_user('alt')
-                    .post_recordset(zone.id, recordset))
-
-        # try with name=zone.com.
-        recordset.name = zone.name
-        self.assertRaises(exceptions.RestClientException,
-            lambda: RecordsetClient.as_user('alt')
-                    .post_recordset(zone.id, recordset))
-
-    def test_no_create_super_recordsets(self):
-        # default creates zone a.b.c.example.com.
-        # alt fails to create record with name b.c.example.com
-        zone_data = datagen.random_zone_data()
-        recordset = datagen.random_a_recordset(zone_name=zone_data.name)
-        recordset.name = 'b.c.' + zone_data.name
-        zone_data.name = 'a.b.c.' + zone_data.name
-
-        fixture = self.useFixture(ZoneFixture(zone_data, user='default'))
-        self.assertRaises(exceptions.RestClientException,
-            lambda: RecordsetClient.as_user('alt')
-                    .post_recordset(fixture.created_zone.id, recordset))
-
-    def test_no_create_recordset_via_alt_domain(self):
-        zone = self.useFixture(ZoneFixture(user='default')).created_zone
-        alt_zone = self.useFixture(ZoneFixture(user='alt')).created_zone
-
-        # alt attempts to create record with name A12345.{zone}
-        recordset = datagen.random_a_recordset(zone_name=zone.name)
-        self.assertRaises(exceptions.RestClientException,
-            lambda: RecordsetClient.as_user('alt')
-                    .post_recordset(zone.id, recordset))
-        self.assertRaises(exceptions.RestClientException,
-            lambda: RecordsetClient.as_user('alt')
-                    .post_recordset(alt_zone.id, recordset))
